Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(3292)

Unified Diff: chrome/browser/ui/passwords/password_manager_presenter.h

Issue 1936053002: [Password Manager] Add federations to sort key on password page (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@2704
Patch Set: Created 4 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | chrome/browser/ui/passwords/password_manager_presenter.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/ui/passwords/password_manager_presenter.h
diff --git a/chrome/browser/ui/passwords/password_manager_presenter.h b/chrome/browser/ui/passwords/password_manager_presenter.h
index 2729cff667b0dba1f30a4415a7fec7aad3a20aff..6ac165f6abb4301454c1e282d71e207482b51b6d 100644
--- a/chrome/browser/ui/passwords/password_manager_presenter.h
+++ b/chrome/browser/ui/passwords/password_manager_presenter.h
@@ -26,6 +26,8 @@ struct PasswordForm;
using DuplicatesMap =
std::multimap<std::string, std::unique_ptr<autofill::PasswordForm>>;
+enum class PasswordEntryType { SAVED, BLACKLISTED };
+
class PasswordUIView;
class Profile;
@@ -79,14 +81,14 @@ class PasswordManagerPresenter
// Sort entries of |list| based on sort key. The key is the concatenation of
// origin, entry type (non-Android credential, Android w/ affiliated web realm
// or Android w/o affiliated web realm). If |username_and_password_in_key|,
// username and password are also included in sort key. If there are several
// forms with the same key, all such forms but the first one are
// stored in |duplicates| instead of |list|.
void SortEntriesAndHideDuplicates(
std::vector<std::unique_ptr<autofill::PasswordForm>>* list,
DuplicatesMap* duplicates,
- bool username_and_password_in_key);
+ PasswordEntryType entry_type);
// A short class to mediate requests to the password store.
class ListPopulater : public password_manager::PasswordStoreConsumer {
« no previous file with comments | « no previous file | chrome/browser/ui/passwords/password_manager_presenter.cc » ('j') | no next file with comments »
@@ -79,14 +81,14 @@ class PasswordManagerPresenter
// Sort entries of |list| based on sort key. The key is the concatenation of
// origin, entry type (non-Android credential, Android w/ affiliated web realm
- // or Android w/o affiliated web realm). If |username_and_password_in_key|,
- // username and password are also included in sort key. If there are several
- // forms with the same key, all such forms but the first one are
+ // or Android w/o affiliated web realm). If |entry_type == SAVED|,
+ // username, password and federation are also included in sort key. If there
+ // are several forms with the same key, all such forms but the first one are
// stored in |duplicates| instead of |list|.
void SortEntriesAndHideDuplicates(

Powered by Google App Engine
This is Rietveld 408576698